@@ -22,11 +22,15 @@ use tracing::{debug, warn};
 
 const DEFAULT_LOCAL_ADDR: (Ipv4Addr, u16) = (Ipv4Addr::UNSPECIFIED, 0);
 
-/// Defaul amount of time to wait for responses to queries before giving up and returning an error.
+/// Default amount of time to wait for responses to queries before giving up and returning an error.
 pub const DEFAULT_QUERY_TIMEOUT: Duration = Duration::from_secs(90);
+/// Default amount of time to wait (to keep the client alive) after sending a command. This allows AE messages to be parsed/resent.
+/// Larger PUT operations may need larger ae wait time
+pub const DEFAULT_AE_WAIT: Duration = Duration::from_secs(5);
 
 const DEFAULT_ROOT_DIR_NAME: &str = "root_dir";
 const SN_CLIENT_QUERY_TIMEOUT: &str = "SN_QUERY_TIMEOUT";
+const SN_CLIENT_AE_WAIT: &str = "SN_AE_WAIT";
 
 /// Configuration for sn_client.
 #[derive(Clone, Debug, Deserialize, Serialize)]
@@ -78,6 +82,7 @@ impl ClientConfig {
         qp2p.keep_alive_interval = Some(Duration::from_secs(30));
 
         let query_timeout = query_timeout.unwrap_or(DEFAULT_QUERY_TIMEOUT);
+        let standard_wait = standard_wait.unwrap_or(DEFAULT_AE_WAIT);
 
         // if we have an env var for this, lets override
         let query_timeout = match std::env::var(SN_CLIENT_QUERY_TIMEOUT) {
@@ -97,13 +102,31 @@ impl ClientConfig {
             Err(_) => query_timeout,
         };
 
+        // if we have an env var for this, lets override
+        let standard_wait = match std::env::var(SN_CLIENT_AE_WAIT) {
+            Ok(timeout) => match timeout.parse() {
+                Ok(time) => {
+                    warn!(
+                        "Client AE wait post-put set from env var {:?}",
+                        SN_CLIENT_AE_WAIT
+                    );
+                    Duration::from_secs(time)
+                }
+                Err(error) => {
+                    warn!("There was an error parsing {:?} env var. Default or client configured query timeout will be used: {:?}", SN_CLIENT_AE_WAIT, error);
+                    standard_wait
+                }
+            },
+            Err(_) => standard_wait,
+        };
+
         Self {
             local_addr: local_addr.unwrap_or_else(|| SocketAddr::from(DEFAULT_LOCAL_ADDR)),
             root_dir: root_dir.clone(),
             genesis_key,
             qp2p,
             query_timeout,
-            standard_wait: standard_wait.unwrap_or(query_timeout / 10),
+            standard_wait,
         }
     }
 }
@@ -202,7 +225,7 @@ mod tests {
                 ..Default::default()
             },
             query_timeout: DEFAULT_QUERY_TIMEOUT,
-            standard_wait: DEFAULT_QUERY_TIMEOUT / 10,
+            standard_wait: DEFAULT_AE_WAIT,
         };
         assert_eq!(format!("{:?}", config), format!("{:?}", expected_config));
         assert_eq!(serialize(&config)?, serialize(&expected_config)?);
